SystemOrganization addCategory: #ConfigurationOfSandstoneDb!

Object subclass: #ConfigurationOfSandstoneDb
	instanceVariableNames: 'project'
	classVariableNames: 'LastVersionLoad'
	poolDictionaries: ''
	category: 'ConfigurationOfSandstoneDb'!

!ConfigurationOfSandstoneDb commentStamp: 'Laurent 3/16/2011 07:40' prior: 0!
SandstoneDb is an object database based on ActiveRecord pattern.

Load last version with:

ConfigurationOfSandstoneDb project latestVersion load.

If you don't want tests:

ConfigurationOfSandstoneDb project latestVersion load: #Core.!

!ConfigurationOfSandstoneDb class methodsFor: 'private' stamp: 'tbn 1/13/2010 13:11'!
bootstrapPackage: aString from: aPath 
	| repository version |
	repository := MCHttpRepository
				location: aPath
				user: ''
				password: ''.
	repository
		versionReaderForFileNamed: aString , '.mcz'
		do: [:reader | 
			version := reader version.
			version load.
			version workingCopy repositoryGroup addRepository: repository]! !

!ConfigurationOfSandstoneDb class methodsFor: 'private' stamp: 'tbn 1/13/2010 13:11'!
ensureMetacello
	"Bootstrap Gofer (if necessary), bootstrap ConfigurationOfMetacello (using old Gofer API), then load the latest 
	version of Metacello itself."

	Smalltalk at: #MetacelloProject ifAbsent: [
		Smalltalk at: #Gofer ifAbsent: [
			"Current version of Gofer from which to bootstrap - as of 1.0-beta.15"
			self bootstrapPackage: 'Gofer-lr.83' from: 'http://seaside.gemstone.com/ss/metacello' ].
		Smalltalk at: #Gofer ifPresent: [:goferClass | | gofer |
			gofer := goferClass new
				url: 'http://seaside.gemstone.com/ss/metacello';
				yourself.
			[ gofer addPackage: 'ConfigurationOfMetacello' ] on: Warning do: [:ex | ex resume ].
			gofer load ].
		"load 'default' group of Metacello"
		(Smalltalk at: #ConfigurationOfMetacello) perform: #load ]! !

!ConfigurationOfSandstoneDb class methodsFor: 'metacello tool support' stamp: 'tbn 1/13/2010 13:10'!
isMetacelloConfig
	"Answer true and the Metacello tools will operate on you"
	
	^true! !

!ConfigurationOfSandstoneDb class methodsFor: 'metacello tool support' stamp: 'tbn 1/13/2010 13:10'!
lastMetacelloVersionLoad
	"Answer the last version loaded and the list of packages loaded for that version."

	LastVersionLoad == nil ifTrue: [ LastVersionLoad := nil -> 'default' ].
	^LastVersionLoad! !

!ConfigurationOfSandstoneDb class methodsFor: 'loading' stamp: 'tbn 2/19/2010 23:18'!
load
	"self load"

	^self project latestVersion load! !

!ConfigurationOfSandstoneDb class methodsFor: 'metacello tool support' stamp: 'tbn 1/13/2010 13:11'!
metacelloVersion: versionString loads: anArrayOrString
	"Stash the last version loaded and the list of packages loaded for that version. The list
	 of packages will be used by the tools when doing 'Load Package Version'"

	LastVersionLoad := versionString -> anArrayOrString! !

!ConfigurationOfSandstoneDb class methodsFor: 'accessing' stamp: 'tbn 1/13/2010 13:10'!
project

	^self new project! !

!ConfigurationOfSandstoneDb methodsFor: 'baselines' stamp: 'tbn 4/26/2010 01:21'!
baseline10: spec
    <version: '1.0-baseline'>
    
    spec for: #pharo do: [
        spec 
			blessing: #baseline;
			description: '1.0 baseline for SandstoneDb';
			repository: 'http://www.squeaksource.com/SandstoneDb'.     
			 
         spec package: 'SandstoneDb' ].		
				
	 							  
    
      
        
! !

!ConfigurationOfSandstoneDb methodsFor: 'baselines' stamp: 'LT 2/1/2011 09:40'!
baseline11: spec
    <version: '1.1-baseline'>
    
    spec for: #common do: [
        spec 
			blessing: #baseline;
			description: '1.1 baseline for SandstoneDb';
			repository: 'http://www.squeaksource.com/SandstoneDb'.     
			 
         spec package: 'SandstoneDb' ].		
	spec for: #squeak do: [
		spec package: 'SandstoneDbSqueak'].
	 							  
    
      
        
! !

!ConfigurationOfSandstoneDb methodsFor: 'baselines' stamp: 'Laurent 3/16/2011 07:46'!
baseline12: spec
    <version: '1.2-baseline'>
    
    spec for: #common do: [
        spec 
			blessing: #baseline;
			description: '1.2 baseline for SandstoneDb';
			repository: 'http://www.squeaksource.com/SandstoneDb'.     
			 
         spec 
		package: 'SandstoneDb';
		package: 'SandstoneDbTests' with:[spec requires: #('SandstoneDb') ]. 
		
	spec 
		group: 'default' with: #('Core' 'Tests');
		group: 'Core' with: #('SandstoneDb');
		group: 'Tests' with: #('SandstoneDbTests') ].
	
			
	spec for: #squeak do: [
		spec package: 'SandstoneDbSqueak' ].
    
      
        
! !

!ConfigurationOfSandstoneDb methodsFor: 'accessing' stamp: 'tbn 1/13/2010 13:05'!
project

	^ project ifNil: [ | constructor |
		"Bootstrap Metacello if it is not already loaded"
		self class ensureMetacello.
		"Construct Metacello project"
		constructor := (Smalltalk at: #MetacelloVersionConstructor) on: self.
		project := constructor project.
		project loadType: #linear.
		project ]! !

!ConfigurationOfSandstoneDb methodsFor: 'versions' stamp: 'tbn 4/26/2010 01:20'!
version10: spec
	<version: '1.0' imports: #('1.0-baseline')>
	
	spec for: #common do: [
		spec blessing: #release.
		spec description: 'first release'. 
		spec author: 'Torsten Bergmann'.
		spec timestamp: '4/25/2010 8:49'.
		spec package: 'SandstoneDb' with: 'SandstoneDb-rjl.119'
	]! !

!ConfigurationOfSandstoneDb methodsFor: 'versions' stamp: 'LT 2/1/2011 09:42'!
version11: spec
	<version: '1.1' imports: #('1.1-baseline')>
	
	spec for: #common do: [
		spec blessing: #release.
		spec description: 'Second release'. 
		spec author: 'Torsten Bergmann'.
		spec timestamp: '4/25/2010 8:49'.
		spec package: 'SandstoneDb' with: 'SandstoneDb-rjl.120'
	].
	spec for: #squeak do: [
		spec 
			package: 'SandstoneDbSqueak' 
			with: 'SandstoneDbSqueak-RamonLeon.1'].! !

!ConfigurationOfSandstoneDb methodsFor: 'versions' stamp: 'Laurent 3/16/2011 07:39'!
version12: spec
	<version: '1.2' imports: #('1.2-baseline')>
	
	spec for: #common do: [
		spec blessing: #release.
		spec description: 'Tests and Core now in seperated packages'. 
		spec author: 'Laurent Laffont'.
		spec timestamp: '3/16/2011 7:38'.
		spec 
			package: 'SandstoneDb' with: 'SandstoneDb-RamonLeon.125';
			package: 'SandstoneDbTests' with: 'SandstoneDbTests-RamonLeon.1'.   
	].

	spec for: #squeak do: [
		spec 
			package: 'SandstoneDbSqueak' 
			with: 'SandstoneDbSqueak-RamonLeon.1'].! !

!ConfigurationOfSandstoneDb methodsFor: 'versions' stamp: 'RamonLeon 3/31/2011 21:51'!
version13: spec
	<version: '1.3' imports: #('1.2-baseline')>
	
	spec for: #common do: [
		spec blessing: #release.
		spec description: 'Cleanly handle class and semaphor serialization errors instead of crashing'. 
		spec author: 'Ramon Leon'.
		spec timestamp: '3/31/2011 9:50'.
		spec 
			package: 'SandstoneDb' with: 'SandstoneDb-RamonLeon.126';
			package: 'SandstoneDbTests' with: 'SandstoneDbTests-RamonLeon.2'.   
	].

	spec for: #squeak do: [
		spec 
			package: 'SandstoneDbSqueak' 
			with: 'SandstoneDbSqueak-RamonLeon.1'].! !

!ConfigurationOfSandstoneDb methodsFor: 'versions' stamp: 'RamonLeon 4/22/2011 13:08'!
version14: spec
	<version: '1.4' imports: #('1.2-baseline')>
	
	spec for: #common do: [
		spec blessing: #release.
		spec description: 'Refactoring to remove duplication and serious performance improvements for the default file store for id queries and deletes'. 
		spec author: 'Ramon Leon'.
		spec timestamp: '4/22/2011 1:07'.
		spec 
			package: 'SandstoneDb' with: 'SandstoneDb-RamonLeon.130';
			package: 'SandstoneDbTests' with: 'SandstoneDbTests-RamonLeon.3'.   
	].

	spec for: #squeak do: [
		spec 
			package: 'SandstoneDbSqueak' 
			with: 'SandstoneDbSqueak-RamonLeon.1'].! !
